<?php

namespace Drupal\sessionless_session;

use Drupal\sticky_query\StickyQueryStorage\StickyQueryStorageInterface;
use Symfony\Component\HttpFoundation\Session\SessionBagInterface;
use Symfony\Component\HttpFoundation\Session\SessionInterface;

/**
 * A (partially crippled) fake session using signed and encrypted sticky query.
 */
class SessionlessSession implements SessionInterface {

  protected StickyQueryStorageInterface $storage;

  protected bool $encrypt;

  public function __construct(StickyQueryStorageInterface $storage, bool $encrypt = TRUE) {
    $this->storage = $storage;
    $this->encrypt = $encrypt;
  }


  public function start() {}

  public function getId() {
    return 'sessionless';
  }

  public function setId($id) {}

  public function getName() {
    return 'sessionless';
  }

  public function setName($name) {}

  public function invalidate($lifetime = NULL) {
    $this->storage->setValue(NULL);
  }

  public function migrate($destroy = FALSE, $lifetime = NULL) {}

  public function save() {}

  public function has($name) {
    $array = $this->storage->getValue();
    return isset($array[$name]);
  }

  public function get($name, $default = NULL) {
    $array = $this->storage->getValue();
    return $array[$name] ?? $default;
  }

  public function set($name, $value) {
    $array = $this->storage->getValue();
    $array[$name] = $value;
    $this->storage->setValue($array);
  }

  public function all() {
    return $this->storage->getValue();
  }

  public function replace(array $attributes) {
    $array = $this->storage->getValue();
    $array = $attributes + $array;
    $this->storage->setValue($array);
  }

  public function remove($name) {
    $array = $this->storage->getValue();
    unset($array[$name]);
    $this->storage->setValue($array);
  }

  public function clear() {
    $this->storage->setValue(NULL);
  }

  public function isStarted() {
    return TRUE;
  }

  public function registerBag(SessionBagInterface $bag) {
    return new \BadMethodCallException(sprintf('Method %s not allowed.', __METHOD__));
  }

  public function getBag($name) {
    return new \BadMethodCallException(sprintf('Method %s not allowed.', __METHOD__));
  }

  public function getMetadataBag() {
    return new \BadMethodCallException(sprintf('Method %s not allowed.', __METHOD__));
  }

}
